# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from cms.plugin_pool import plugin_pool
from cmsplugin_bootstrap.change_form_widgets import ExtraStylesWidget
from cmsplugin_bootstrap.plugin_base import BootstrapPluginBase, CSS_MARGIN_STYLES


class CarouselPlugin(BootstrapPluginBase):
    name = _("Carousel")
    render_template = 'cms/plugins/bootstrap/carousel.html'
    child_classes = ['SlidePlugin']
    css_class_choices = (('slide', 'slide'),)
    extra_styles_widget = ExtraStylesWidget(CSS_MARGIN_STYLES + ['width', 'height'])
    options_widget = ExtraStylesWidget(['interval', 'pause'])

plugin_pool.register_plugin(CarouselPlugin)


class SlidePlugin(BootstrapPluginBase):
    name = _("Slide")
    render_template = 'cms/plugins/bootstrap/carousel-slide.html'
    parent_classes = ['CarouselPlugin']
    require_parent = True
    child_classes = ['TextPlugin', 'FilerImagePlugin']
    css_class_choices = (('item', 'item'),)

plugin_pool.register_plugin(SlidePlugin)



from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.text import Truncator
from jsonfield.fields import JSONField
from cms.models import CMSPlugin


class BootstrapElement(CMSPlugin):
    """
    The container to hold additional bootstrap elements.
    """
    cmsplugin_ptr = models.OneToOneField(CMSPlugin, related_name='+', parent_link=True)
    tag_type = models.CharField(verbose_name=_('tag Type'), max_length=50)
    class_name = models.CharField(_("class name"), max_length=50, blank=True, null=True)
    extra_classes = JSONField(null=True, blank=True, help_text='Add extra CSS classes to this HTML element')
    tagged_classes = JSONField(null=True, blank=True, help_text='Tag special CSS classes to this HTML element')
    extra_styles = JSONField(null=True, blank=True, help_text='Add extra styles to this HTML element')
    options = JSONField(null=True, blank=True, help_text='Extra data options for this plugin')

    def __unicode__(self):
        value = self.css_classes
        if value:
            return unicode(Truncator(value).words(3, truncate=' ...'))
        return u''

    @property
    def css_classes(self):
        css_classes = self.class_name and [self.class_name] or []
        if isinstance(self.extra_classes, dict):
            css_classes.extend([ec for ec in self.extra_classes.values() if ec])
        if isinstance(self.tagged_classes, list):
            css_classes.extend([tc for tc in self.tagged_classes if tc])
        return u' '.join(css_classes)

    @property
    def inline_styles(self):
        if isinstance(self.extra_styles, dict):
            try:
                return u' '.join(['{0}: {1};'.format(*s) for s in self.extra_styles.items() if s[1] is not None])
            except IndexError:
                pass
        return ''

    @property
    def data_options(self):
        if isinstance(self.options, dict):
            try:
                return u' '.join(['data-{0}={1}'.format(*s) for s in self.options.items() if s[1] is not None])
            except IndexError:
                pass
        return ''



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from cms.plugin_pool import plugin_pool
from cmsplugin_bootstrap.change_form_widgets import (ExtraStylesWidget, MultipleRadioButtonsWidget,
    MultipleCheckboxesWidget)
from cmsplugin_bootstrap.plugin_base import BootstrapPluginBase, CSS_MARGIN_STYLES


class ButtonWrapperPlugin(BootstrapPluginBase):
    name = _("Button wrapper")
    render_template = "cms/plugins/bootstrap/naked.html"
    child_classes = ['LinkPlugin']
    tag_type = 'naked'
    css_class_choices = (('btn', 'btn'),)
    extra_classes_widget = MultipleRadioButtonsWidget((
        ('buttontype', (('', 'unstyled'),) + tuple(2 * ('btn-%s' % b,)
            for b in ('primary', 'info', 'success', 'warning', 'danger', 'inverse', 'link'))),
        ('buttonsize', (('', 'default'),) + tuple(2 * ('btn-%s' % b,)
            for b in ('large', 'small', 'mini',))),
    ))
    tagged_classes_widget = MultipleCheckboxesWidget((('disabled', 'disabled'),))
    extra_styles_widget = ExtraStylesWidget(CSS_MARGIN_STYLES)

plugin_pool.register_plugin(ButtonWrapperPlugin)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'BootstrapElement'
        db.create_table(u'cmsplugin_bootstrapelement', (
            ('cmsplugin_ptr', self.gf('django.db.models.fields.related.OneToOneField')(related_name='+', unique=True, primary_key=True, to=orm['cms.CMSPlugin'])),
            ('tag_type', self.gf('django.db.models.fields.CharField')(max_length=50)),
            ('class_name', self.gf('django.db.models.fields.CharField')(max_length=50, null=True, blank=True)),
            ('extra_classes', self.gf('jsonfield.fields.JSONField')(null=True, blank=True)),
            ('tagged_classes', self.gf('jsonfield.fields.JSONField')(null=True, blank=True)),
            ('extra_styles', self.gf('jsonfield.fields.JSONField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'cmsplugin_bootstrap', ['BootstrapElement'])


    def backwards(self, orm):
        # Deleting model 'BootstrapElement'
        db.delete_table(u'cmsplugin_bootstrapelement')


    models = {
        'cms.cmsplugin': {
            'Meta': {'object_name': 'CMSPlugin'},
            'changed_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.CMSPlugin']", 'null': 'True', 'blank': 'True'}),
            'placeholder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'plugin_type': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'position': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'})
        },
        u'cmsplugin_bootstrap.bootstrapelement': {
            'Meta': {'object_name': 'BootstrapElement', 'db_table': "u'cmsplugin_bootstrapelement'", '_ormbases': ['cms.CMSPlugin']},
            'class_name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'}),
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'related_name': "'+'", 'unique': 'True', 'primary_key': 'True', 'to': "orm['cms.CMSPlugin']"}),
            'extra_classes': ('jsonfield.fields.JSONField', [], {'null': 'True', 'blank': 'True'}),
            'extra_styles': ('jsonfield.fields.JSONField', [], {'null': 'True', 'blank': 'True'}),
            'tag_type': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'tagged_classes': ('jsonfield.fields.JSONField', [], {'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['cmsplugin_bootstrap']


# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.importlib import import_module

bootstrap_plugins = ['buttons', 'container', 'thumbnails', 'carousel']

for plugin in getattr(settings, 'CMSPLUGIN_BOOTSTRAP_PLUGINS', bootstrap_plugins):
    import_module('cmsplugin_bootstrap.' + plugin)



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from cms.plugin_pool import plugin_pool
from cmsplugin_bootstrap.plugin_base import BootstrapPluginBase


class BootstrapThumbnailsPlugin(BootstrapPluginBase):
    name = _("Thumbnails")
    child_classes = ['BootstrapThumbImagePlugin']
    tag_type = 'ul'
    css_class_choices = (('thumbnails', 'thumbnails'),)

plugin_pool.register_plugin(BootstrapThumbnailsPlugin)


class BootstrapThumbImagePlugin(BootstrapPluginBase):
    name = _("Single thumbnail")
    parent_classes = ['BootstrapThumbnailsPlugin']
    require_parent = True
    tag_type = 'li'
    css_class_choices = (('thumbnail', 'thumbnail'),)

plugin_pool.register_plugin(BootstrapThumbImagePlugin)



# -*- coding: utf-8 -*-
import json
from django.forms import widgets
from django.utils.safestring import mark_safe


class JSONMultiWidget(widgets.MultiWidget):
    """Base class for MultiWidgets using a JSON field in database"""
    def decompress(self, value):
        values = value and json.loads(value) or {}
        for prefix in self.prefixes:
            values.setdefault(prefix, None)
        return values

    def value_from_datadict(self, data, files, name):
        result = dict((p, data.get(p) or None) for p in self.prefixes)
        return result

    def render(self, name, value, attrs=None):
        values = self.decompress(value)
        html = '<div class="multi-widget-row">'
        for index, prefix in enumerate(self.prefixes):
            html += self.widgets[index].render(prefix, values.get(prefix), attrs)
        html += '</div>'
        return mark_safe(html)


class ExtraStylesWidget(JSONMultiWidget):
    """
    Creates one or more independent text fields to keep extra styles applied to the
    corresponding HTML element.
    """
    def __init__(self, styles):
        margin_widgets = [widgets.TextInput({ 'placeholder': s }) for s in styles]
        super(ExtraStylesWidget, self).__init__(margin_widgets)
        self.prefixes = styles[:]


class MultipleRadioButtonsWidget(JSONMultiWidget):
    """
    Creates one or more independent rows of radio button widgets, each of which declares its own
    choices. widget_choices shall be a tuple of tuples containing the name followed by a tuple
    of two-choices of choices.
    """
    def __init__(self, choices):
        if not choices or not isinstance(choices, (list, tuple)) or not isinstance(choices[0], tuple):
            raise AttributeError('choices must be list or tuple of tuples')
        radio_widgets = dict((key, widgets.RadioSelect(choices=ch)) for key, ch in choices)
        super(MultipleRadioButtonsWidget, self).__init__(radio_widgets.values())
        self.prefixes = radio_widgets.keys()


class MultipleCheckboxesWidget(widgets.CheckboxSelectMultiple):
    """
    Creates one or more independent rows of radio button widgets, each of which declares its own
    choices. widget_choices shall be a tuple of tuples containing the name followed by a tuple
    of two-choices of choices.
    """
    def __init__(self, choices):
        if not choices or not isinstance(choices, (list, tuple)) or not isinstance(choices[0], tuple):
            raise AttributeError('choices must be list or tuple of tuples')
        super(MultipleCheckboxesWidget, self).__init__(choices=choices)
        self.labels = [choice[0] for choice in choices]

    def render(self, name, value, attrs=None):
        values = value and json.loads(value) or []
        values += [None] * (len(self.labels) - len(values))
        html = '<div class="multi-widget-row">'
        html += super(MultipleCheckboxesWidget, self).render(name, values, attrs)
        html += '</div>'
        return mark_safe(html)



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from cms.plugin_pool import plugin_pool
from cmsplugin_bootstrap.change_form_widgets import ExtraStylesWidget, MultipleRadioButtonsWidget
from cmsplugin_bootstrap.plugin_base import BootstrapPluginBase, CSS_VERTICAL_SPACING


class BootstrapRowPlugin(BootstrapPluginBase):
    name = _("Row container")
    child_classes = ['BootstrapColumnPlugin']
    tag_type = 'div'
    css_class_choices = (('row', 'row'), ('row-fluid', 'row-fluid'))
    extra_styles_widget = ExtraStylesWidget(CSS_VERTICAL_SPACING)

plugin_pool.register_plugin(BootstrapRowPlugin)


class BootstrapColumnPlugin(BootstrapPluginBase):
    name = _("Column container")
    parent_classes = ['BootstrapRowPlugin']
    require_parent = True
    tag_type = 'div'
    css_class_choices = tuple(2 * ('span%s' % i,) for i in range(1, 13))
    extra_classes_widget = MultipleRadioButtonsWidget((
        ('offset', (('', 'no offset'),) + tuple(2 * ('offset%s' % o,) for o in range(1, 12))),
    ))
    extra_styles_widget = ExtraStylesWidget(CSS_VERTICAL_SPACING)

plugin_pool.register_plugin(BootstrapColumnPlugin)


class BootstrapDivPlugin(BootstrapPluginBase):
    name = _("Simple div container")
    parent_classes = ['BootstrapColumnPlugin']
    require_parent = True
    tag_type = 'div'
    css_class_choices = (('', '---'), ('hero-unit', 'hero-unit'))
    extra_styles_widget = ExtraStylesWidget(CSS_VERTICAL_SPACING)

plugin_pool.register_plugin(BootstrapDivPlugin)


class HorizontalRulePlugin(BootstrapPluginBase):
    name = _("Horizontal Rule")
    require_parent = False
    allow_children = False
    tag_type = 'hr'
    render_template = 'cms/plugins/bootstrap/single.html'
    extra_styles_widget = ExtraStylesWidget(['margin-top', 'margin-bottom'])

plugin_pool.register_plugin(HorizontalRulePlugin)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup
from cmsplugin_bootstrap import __version__


INSTALL_REQUIRES = [

]

CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
]

setup(
    name='djangocms-bootstrap',
    version=__version__,
    description='Collection of plugins for DjangoCMS',
    author='Jacob Rief',
    author_email='jacob.rief@gmail.com',
    url='https://github.com/jrief/djangocms-bootstrap',
    packages=['cmsplugin_bootstrap', 'cmsplugin_bootstrap.migrations'],
    install_requires=INSTALL_REQUIRES,
    license='LICENSE-MIT',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    long_description=open('README.md').read(),
    include_package_data=True,
    zip_safe=False
)



# -*- coding: utf-8 -*-
from django.forms import widgets
from django.forms.models import modelform_factory
from django.utils.datastructures import SortedDict
from cms.plugin_base import CMSPluginBase
from cmsplugin_bootstrap.models import BootstrapElement

CSS_MARGIN_STYLES = ['margin-%s' % s for s in ('top', 'right', 'bottom', 'left')]
CSS_VERTICAL_SPACING = ['min-height']


class BootstrapPluginBase(CMSPluginBase):
    module = 'Bootstrap'
    model = BootstrapElement
    tag_type = 'div'
    change_form_template = "cms/plugins/bootstrap/change_form.html"
    render_template = "cms/plugins/bootstrap/generic.html"
    allow_children = True

    def __init__(self, *args, **kwargs):
        super(BootstrapPluginBase, self).__init__(*args, **kwargs)
        change_form_widgets = SortedDict()
        if hasattr(self, 'css_class_choices') and len(self.css_class_choices) > 1:
            change_form_widgets['class_name'] = widgets.Select(choices=self.css_class_choices)
        if hasattr(self, 'extra_classes_widget'):
            change_form_widgets['extra_classes'] = self.extra_classes_widget
        if hasattr(self, 'tagged_classes_widget'):
            change_form_widgets['tagged_classes'] = self.tagged_classes_widget
        if hasattr(self, 'extra_styles_widget'):
            change_form_widgets['extra_styles'] = self.extra_styles_widget
        if hasattr(self, 'options_widget'):
            change_form_widgets['options'] = self.options_widget
        self.form = modelform_factory(BootstrapElement, fields=change_form_widgets.keys(), widgets=change_form_widgets)

    def save_model(self, request, obj, form, change):
        obj.tag_type = self.tag_type
        if hasattr(self, 'css_class_choices') and len(self.css_class_choices) == 1:
            obj.class_name = self.css_class_choices[0][0]
        return super(BootstrapPluginBase, self).save_model(request, obj, form, change)
